@@ -60,10 +60,14 @@ var baseUrl string
 
 // tables to include
 var includes []string
+var tables []string
 
 // tables to excludes
 var excludes []string
 
+// table labels to be included
+var labels []string
+
 const rootUsageTemplate = `Usage:{{if .Runnable}}{{if ne .UseLine "tbls [flags]" }}
   {{.UseLine}}{{end}}{{end}}{{if .HasAvailableSubCommands}}
   {{.CommandPath}} [command]{{end}}{{if gt (len .Aliases) 0}}
